

/*
my code uses 2 changes:
1/ computing the position of colgroup
2/ event delegation (I'll describe it in the function when it's used)

ad 1/ there are 2 jQuery functions
a) $(selector).index(arguments) returning the position of element inside 
other elemets / parent / list of elements according to markup, 
so if I hover over 3td cell in a row, it will return 2 (it's zero based), 
see quite an improvement in coding between 1.3.2 and 1.4.2 versions of jQuery

b) $(selector).eq(index) returns jquery object that is at passed position in 
the result of selection using selector (according to markup and it's zero based)

so combining the retrieving the index of the cell in a row and finding matching 
colgroup this could be done dome much more easier


ad 2/ I've described the problem in my comment, your using way too much event 
assignment, this could have significant performance effects on heavy pages or 
older browsers, my approach uses event delegation 
(live for 1.3.2 and delegate for 1.4.2 [but you can use live the same way in 1.4.2])). 
The nice added bonus I mention in my comment will be described below the whole function :)!!!!
*/

$(function() {

/*

this code is used for jQuery 1.3.2 (version in your original example), 
this version does not have delegate method

so what does $(selector).live do (since there is technically no hover event 
I've coded mouseover and mouseout)?

1/ attach event to the document (not to the elements)
2/ when event occures on document, it's triggered on the document (it will simply bubble up
through the DOM, it's common event feature, this happens in browser itself, in all browsers)
3/ jQuery matches the target element (where the bubbeling begins) against the selector and 
the context (the 1st and the 2nd parameter of jQuery selection) and if it matches than event 
function is triggered with the correct context (value of "this" variable)

this should be used carefully in case of event like mouseover since this events are called 
very often (everytime user moves the mouse), events like click are fine. But this issue is 
solved with delegate method, there are more problems with live method (like no chaining, etc.)...




    $("td", $("table")[0]).live('mouseover', function(e) {
      $(this).parent().addClass("hover");
      $("colgroup").eq($(this).parent().find("td").index($(this)[0])).addClass("hover");
    });

    $("td", $("table")[0]).live('mouseout', function() {
      $(this).parent().removeClass("hover");
      $("colgroup").eq($(this).parent().find("td").index($(this)[0])).removeClass("hover");
    });
*/



/*
code for 1.4.2

1/ delegate does similar functionality but differently, it attaches event to the selector 
(table in this case) 
2/ once event, specified by second parameter, is fired on that element (table) by browser,
it checks whether it matches the first parameter (td) 
3/ and if it does, delegate triggers event function passed as 3rd parameter with correct value 
of "this" variable

this does not have issues mentioned above when describing live method, since it does not 
bind the event with the whole document, but only with the table (and chaining applies here)

again, since hover is not an event, I'm passing 2 events separated by space and checking for the 
type of it 


and the bonus is below :)
*/

    $("table").delegate('td','mouseover mouseout', function(e) {
        if (e.type == 'mouseover')
        {
          $(this).parent().addClass("hover");
          $("colgroup").eq($(this).index()).addClass("hover");
        }
        else
        {
          $(this).parent().removeClass("hover");
          $("colgroup").eq($(this).index()).removeClass("hover");
        }
    });

});

/*
The "bonus" is actually not a bonus of event delegation, it's the purpose of live 
(delegate is just more efficient and pleasant way of doing live). 
Imagine your original code, if new rows appear (e.g. you download some additional
data using AJAX and append new rows), your code will not work for those new rows (cells), 
because there is no event attached to them, so you would have to run your code again. 
Event delegation does not attach event to cells but to parent element 
(or document, or whatever element you use for delegate method) and then only checks 
the target of the event, so new cells will pass this check and event is triggered 
(hence "live": event are triggered as being live, like they are attached to cells as 
they appear on the page later [actually not to cells, but it behaves like that])

*/

